#
# spec file for package cabal-install
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cabal-install
Version:        3.2.0.0
Release:        bp155.4.50
Summary:        The command-line interface for Cabal and Hackage
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{name}
Source0:        https://hackage.haskell.org/package/%{name}-%{version}/%{name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{name}-%{version}/revision/1.cabal#/%{name}.cabal
Patch01:        ghc-8.10-support-for-3.2.patch
Patch02:        base16-bytestring.patch
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-HTTP-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-async-devel
BuildRequires:  ghc-base16-bytestring-devel
BuildRequires:  ghc-binary-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-cryptohash-sha256-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-echo-devel
BuildRequires:  ghc-edit-distance-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-hackage-security-devel
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-lukko-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-network-devel
BuildRequires:  ghc-network-uri-devel
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-pretty-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-random-devel
BuildRequires:  ghc-resolv-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-stm-devel
BuildRequires:  ghc-tar-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-unix-devel
BuildRequires:  ghc-zlib-devel
ExcludeArch:    %{ix86}

%description
The 'cabal' command-line program simplifies the process of managing Haskell
software by automating the fetching, configuration, compilation and
installation of Haskell libraries and programs.

%prep
%autosetup -p2
cp -p %{SOURCE1} %{name}.cabal
cabal-tweak-dep-ver random '< 1.2' '< 1.3'
cabal-tweak-dep-ver base '< 4.14' '< 5'
cabal-tweak-dep-ver base16-bytestring '< 0.2' '< 2'

%build
%ghc_bin_build

%install
%ghc_bin_install

%files
%license LICENSE
%doc README.md changelog
%{_bindir}/cabal
%{_mandir}/man1/cabal.1%{?ext_man}

%changelog
* Wed Jan  5 2022 Peter Simons <psimons@suse.com>
- Update cabal-install to version 3.2.0.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Oct 13 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add _constraints
* Tue Aug 17 2021 Ondřej Súkup <mimi.vx@gmail.com>
- relax dependency on random
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Thu Dec 10 2020 Ondřej Súkup <mimi.vx@gmail.com>
- add base16-bytestring.patch for build with new base16-bytestring
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Wed May  6 2020 psimons@suse.com
- Update cabal-install to version 3.2.0.0.
  * `v2-build` (and other `v2-`prefixed commands) now accept the
    `--benchmark-option(s)` flags, which pass options to benchmark executables
    (analogous to how `--test-option(s)` works). (#6209)
  * Add solver optimization to skip a version of a package if it does not resolve
    any conflicts encountered in the last version, controlled by flag
    '--fine-grained-conflicts'. (#5918)
  * `cabal v2-exec` doesn't fail in clean package (#6479)
  * Show full ABI hash for installed packages in solver log (#5892)
  * Create incoming directory even for empty packages (#4130)
  * Start GHCi with `main-is` module in scope (#6311)
  * Implement `--benchmark-options` for `v2-bench` (#6224)
  * Fix store-dir in ghc env files generated by `cabal install --lib
  - -package-env` (#6298)
  * `cabal v2-run` works with `.lhs` files (#6134)
  * `subdir` in source-repository-package accepts multiple entries (#5472)
  * Create store incoming directory
    ([#4130](https://github.com/haskell/cabal/issues/4130))
  * `fetchRepoTarball` output is not marked
    ([#6385](https://github.com/haskell/cabal/pull/6385))
  * Update `setupMinCabalVersionConstraint` for GHC-8.8
    ([#6217](https://github.com/haskell/cabal/pull/6217))
  * Implement `cabal install --ignore-project`
    ([#5919](https://github.com/haskell/cabal/issues/5919))
  * `cabal install executable` solver isn't affected by default
    environment contents
    ([#6410](https://github.com/haskell/cabal/issues/6410))
  * Use `lukko` for file locking
    ([#6345](https://github.com/haskell/cabal/pull/6345))
  * Use `hackage-security-0.6`
    ([#6388](https://github.com/haskell/cabal/pull/6388))
  * Other dependency upgrades
- Apply "ghc-8.10-support-for-3.2.patch" from upstream's git
  repository to fix the build with ghc-8.10.1.
* Mon Mar  9 2020 Ondřej Súkup <mimi.vx@gmail.com>
- relax constraints on network-uri
* Sun Dec 29 2019 psimons@suse.com
- Update cabal-install to version 3.0.0.0.
  * `v2-haddock` fails on `haddock` failures (#5977)
  * `v2-run` works when given `File.lhs` literate file. (#6134)
  * Parse comma-separated lists for extra-prog-path, extra-lib-dirs, extra-framework-dirs,
    and extra-include-dirs as actual lists. (#5420)
  * `v2-repl` no longer changes directory to a randomized temporary folder
    when used outside of a project. (#5544)
  * `install-method` and `overwrite-policy` in `.cabal/config` now actually work. (#5942)
  * `v2-install` now reports the error when a package fails to build. (#5641)
  * `v2-install` now has a default when called in a project (#5978, #6014, #6092)
  * '--write-ghc-environment-files' now defaults to 'never' (#4242)
  * Fix `sdist`'s output when sent to stdout. (#5874)
  * Allow a list of dependencies to be provided for `repl --build-depends`. (#5845)
  * Legacy commands are now only accessible with the `v1-` prefixes, and the `v2-`
    commands are the new default. Accordingly, the next version of Cabal will be
    the start of the 3.x version series. (#5800)
  * New solver flag: '--reject-unconstrained-dependencies'. (#2568)
  * Ported old-style test options to the new-style commands (#5455).
  * Improved error messages for cabal file parse errors. (#5710)
  * Removed support for `.zip` format source distributions (#5755)
  * Add "simple project" initialization option. (#5707)
  * Add '--minimize-conflict-set' flag to try to improve the solver's
    error message, but with an increase in run time. (#5647)
  * v2-test now succeeds when there are no test suites. (#5435)
  * Add '--lib', '--exe', and '--libandexe' shorthands to init. (#5759)
  * init now generates valid `Main.lhs` files. (#5577)
  * Init improvements: add flag '--application-dir', and when creating
    a library also create a MyLib.hs module. (#5740)
  * Add support for generating test-suite via cabal init. (#5761)
  * Increase `max-backjumps` default from 2000 to 4000.
  * Make v2-install/new-install-specific flags configurable in
    ~/.cabal/config
  * Add --installdir and --install-method=copy flags to v2-install
    that make it possible to copy the executable instead of symlinking it
  * --symlink-bindir no longer controls the symlinking directory of
    v2-install (installdir controls both symlinking and copying now)
  * Default to non-interactive init.
  * Add --test-wrapper that allows a prebuild script to set the test environment.
  * Add filterTestFlags: filter test-wrapper for Cabal < 3.0.0.
  * Cabal now only builds the minimum of a package for `v2-install` (#5754, #6091)
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Sat Dec  8 2018 Peter Simons <psimons@suse.com>
- Tweak Cabal build instructions to accept zip-archive 0.4.x.
* Sun Dec  2 2018 Peter Simons <psimons@suse.com>
- Update Cabal build instructions to support network version 2.8.x.
* Thu Oct  4 2018 psimons@suse.com
- Update cabal-install to version 2.4.0.0.
  * Bugfix: "cabal new-build --ghc-option '--bogus' --ghc-option '-O1'"
    no longer ignores all arguments except the last one (#5512).
  * Add the following option aliases for '-dir'-suffixed options:
    'storedir', 'logsdir', 'packagedir', 'sourcedir', 'outputdir' (#5484).
  * 'new-run' now allows the user to run scripts that use a special block
    to define their requirements (as in the executable stanza) in place
    of a target. This also allows the use of 'cabal' as an interpreter
    in a shebang line.
  * Add aliases for the "new-" commands that won't change when they
    lose their prefix or are eventually replaced by a third UI
    paradigm in the future. (#5429)
  * 'outdated' now accepts '--project-file FILE', which will look for bounds
    from the new-style freeze file named FILE.freeze. This is only
    available when `--new-freeze-file` has been passed.
  * 'new-repl' now accepts a '--build-depends' flag which accepts the
    same syntax as is used in .cabal files to add additional dependencies
    to the environment when developing in the REPL. It is now usable outside
    of projects. (#5425, #5454)
  * 'new-build' now treats Haddock errors non-fatally. In addition,
    it attempts to avoid trying to generate Haddocks when there is
    nothing to generate them from. (#5232, #5459)
  * 'new-run', 'new-test', and 'new-bench' now will attempt to resolve
    ambiguous selectors by filtering out selectors that would be invalid.
    (#4679, #5461)
  * 'new-install' now supports installing libraries and local
    components. (#5399)
  * Drop support for GHC 7.4, since it is out of our support window
    (and has been for over a year!).
  * 'new-update' now works outside of projects. (#5096)
  * Extend `plan.json` with `pkg-src` provenance information. (#5487)
  * Add 'new-sdist' command (#5389). Creates stable archives based on
    cabal projects in '.zip' and '.tar.gz' formats.
  * Add '--repl-options' flag to 'cabal repl' and 'cabal new-repl'
    commands. Passes its arguments to the invoked repl, bypassing the
    new-build's cached configurations. This assures they don't trigger
    useless rebuilds and are always applied within the repl. (#4247, #5287)
  * Add 'v1-' prefixes for the commands that will be replaced in the
    new-build universe, in preparation for it becoming the default.
    (#5358)
  * 'outdated' accepts '--v1-freeze-file' and '--v2-freeze-file'
    in the same spirit.
  * Completed the 'new-clean' command (#5357). The functionality is
    equivalent to old-style clean, but for nix-style builds.
  * Ensure that each package selected for a build-depends dependency
    contains a library (#5304).
  * Support packages from local tarballs in the cabal.project file.
  * Default changelog generated by 'cabal init' is now named
    'CHANGELOG.md' (#5441).
  * Align output of 'new-build' command phases (#4040).
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update cabal-install to version 2.2.0.0 revision 1.
  * '--with-PROG' and '--PROG-options' are applied to all packages
    and not local packages only (#5019).
  * Completed the 'new-update' command (#4809), which respects nix-style
    cabal.project(.local) files and allows to update from
    multiple repositories when using overlays.
  * Completed the 'new-run' command (#4477). The functionality is the
    same of the old 'run' command but using nix-style builds.
    Additionally, it can run executables across packages in a project.
    Tests and benchmarks are also treated as executables, providing a
    quick way to pass them arguments.
  * Completed the 'new-bench' command (#3638). Same as above.
  * Completed the 'new-exec' command (#3638). Same as above.
  * Added a preliminary 'new-install' command (#4558, nonlocal exes
    part) which allows to quickly install executables from Hackage.
  * Set symlink-bindir (used by new-install) to .cabal/bin by default on
    .cabal/config initialization (#5188).
  * 'cabal update' now supports '--index-state' which can be used to
    roll back the index to an earlier state.
  * '--allow-{newer,older}' syntax has been enhanced. Dependency
    relaxation can be now limited to a specific release of a package,
    plus there's a new syntax for relaxing only caret-style (i.e. '^>=')
    dependencies (#4575, #4669).
  * New config file field: 'cxx-options' to specify which options to be
    passed to the compiler when compiling C++ sources specified by the
    'cxx-sources' field. (#3700)
  * New config file field: 'cxx-sources' to specify C++ files to be
    compiled separately from C source files. Useful in conjunction with the
    'cxx-options' flag to pass different compiler options to C and C++
    source files. (#3700)
  * Use [lfxtb] letters to differentiate component kind instead of
    opaque "c" in dist-dir layout.
  * 'cabal configure' now supports '--enable-static', which can be
    used to build static libaries with GHC via GHC's `-staticlib`
    flag.
  * 'cabal user-config now supports '--augment' which can append
    additional lines to a new or updated cabal config file.
  * Added support for '--enable-tests' and '--enable-benchmarks' to
    'cabal fetch' (#4948).
  * Misspelled package-names on CLI will no longer be silently
    case-corrected (#4778).
  * 'cabal new-configure' now backs up the old 'cabal.project.local'
    file if it exists (#4460).
  * On macOS, `new-build` will now place dynamic libraries into
    `store/lib` and aggressively shorten their names in an effort to
    stay within the load command size limits of macOSs mach-o linker.
  * 'new-build' now checks for the existence of executables for
    build-tools and build-tool-depends dependencies in the solver
    (#4884).
  * Fixed a spurious warning telling the user to run 'cabal update'
    when it wasn't necessary (#4444).
  * Packages installed in sandboxes via 'add-source' now have
    their timestamps updated correctly and so will not be reinstalled
    unncecessarily if the main install command fails (#1375).
  * Add Windows device path support for copyFile, renameFile. Allows cabal
    new-build to use temporary store path of up to 32k length
    (#3972, #4914, #4515).
  * When a flag value is specified multiple times on the command
    line, the last one is now preferred, so e.g. '-f+dev -f-dev' is
    now equivalent to '-f-dev' (#4452).
  * Removed support for building cabal-install with GHC < 7.10 (#4870).
  * New 'package *' section in 'cabal.project' files that applies
    options to all packages, not just those local to the project.
  * Paths_ autogen modules now compile when `RebindableSyntax` or
    `OverloadedStrings` is used in `default-extensions`.
    [stack#3789](https://github.com/commercialhaskell/stack/issues/3789)
  * getDataDir` and other `Paths_autogen` functions now work
    correctly when compiling a custom `Setup.hs` script using
    `new-build` (#5164).
  * Support for GHC's numeric -g debug levels (#4673).
  * Demoted 'scope' field version check to a warning (#4714).
  * Fixed verbosity flags getting removed before being passed to
    'printPlan' (#4724).
  * Added a '--store-dir' option that can be used to configure the
    location of the build global build store (#4623).
  * Turned `allow-{newer,older}` in `cabal.project` files into an
    accumulating field to match CLI flag semantics (#4679).
  * Improve success message when `cabal upload`ing documentation
    (#4777).
  * Documentation fixes.
  * See http://coldwa.st/e/blog/2017-09-09-Cabal-2-0.html
    for more detailed release notes.
  * Removed the '--root-cmd' parameter of the 'install' command
    (#3356).
  * Deprecated 'cabal install --global' (#3356).
  * Changed 'cabal upload' to upload a package candidate by default
    (#3419). Same applies to uploading documentation.
  * Added a new 'cabal upload' flag '--publish' for publishing a
    package on Hackage instead of uploading a candidate (#3419).
  * Added optional solver output visualisation support via the
    tracetree package. Mainly intended for debugging (#3410).
  * Removed the '--check' option from 'cabal upload'
    (#1823). It was replaced by package candidates.
  * Fixed various behaviour differences between network transports
    (#3429).
  * The bootstrap script now works correctly when run from a Git
    clone (#3439).
  * Removed the top-down solver (#3598).
  * The '-v/--verbosity' option no longer affects GHC verbosity
    (except in the case of '-v0'). Use '--ghc-options=-v' to enable
    verbose GHC output (#3540, #3671).
  * Changed the default logfile template from
    '.../$pkgid.log' to '.../$compiler/$libname.log' (#3807).
  * Added a new command, 'cabal reconfigure', which re-runs 'configure'
    with the most recently used flags (#2214).
  * Added the '--index-state' flag for requesting a specific
    version of the package index (#3893, #4115).
  * Support for building Backpack packages.  See
    https://github.com/ezyang/ghc-proposals/blob/backpack/proposals/0000-backpack.rst
    for more details.
  * Support the Nix package manager (#3651).
  * Made the 'template-haskell' package non-upgradable again (#4185).
  * Fixed password echoing on MinTTY (#4128).
  * Added a new solver flag, '--allow-boot-library-installs', that allows
    any package to be installed or upgraded (#4209).
  * New 'cabal-install' command: 'outdated', for listing outdated
    version bounds in a .cabal file or a freeze file (#4207).
  * Added qualified constraints for setup dependencies. For example,
  - -constraint="setup.bar == 1.0" constrains all setup dependencies on
    bar, and --constraint="foo:setup.bar == 1.0" constrains foo's setup
    dependency on bar (part of #3502).
  * Non-qualified constraints, such as --constraint="bar == 1.0", now
    only apply to top-level dependencies. They don't constrain setup or
    build-tool dependencies. The new syntax --constraint="any.bar == 1.0"
    constrains all uses of bar.
  * Added a technical preview version of the 'cabal doctest' command
    (#4480).
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Sat May 27 2017 psimons@suse.com
- Update to version 1.24.0.2 revision 1.
* Wed Apr 26 2017 psimons@suse.com
- Add bash-completion sub-package that provides the auto-completion
  instructions for bash.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 1.24.0.2 with cabal2obs.
* Mon Nov 21 2016 psimons@suse.com
- Update to version 1.24.0.0 revision 2 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 1.24.0.0 revision 1 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 1.22.9.0 revision 0 with cabal2obs.
* Mon Mar  7 2016 mimi.vx@gmail.com
- update to 1.22.9.0
  * Include Cabal-1.22.8.0
* Mon Feb  1 2016 mimi.vx@gmail.com
- update to 1.22.8.0
  * Only Custom setup scripts should be compiled with '-i -i.'.
  * installedCabalVersion: Don't special-case Cabal anymore.
  * Bump the HTTP upper bound.
* Sun Jan 24 2016 mimi.vx@gmail.com
- relax HTTP dep
* Mon Dec 28 2015 mimi.vx@gmail.com
- update to 1.22.7.0
  * Remove GZipUtils tests
  * maybeDecompress: bail on all errors at the beginning of the stream with zlib < 0.6
  * Correct maybeDecompress
* Wed Jul  8 2015 peter.trommler@ohm-hochschule.de
- update to 1.22.6.0
  * work with ghc 7.10
  * bug fixes
* Sun May 10 2015 mimi.vx@gmail.com
- update to 1.18.1.0
  * Force cabal upload to always use digest auth and never basic auth.
  * Merge pull request #2367 from juhp/patch-2
  * Fix bootstrap.sh by bumping HTTP to 4000.2.16.1
* Fri Apr 10 2015 mimi.vx@gmail.com
- update to 1.18.0.8
  * Support random 1.1.
  * Fix bootstrap script after network package split.
  * Support network-2.6 in test suite.
* Tue Sep  2 2014 peter.trommler@ohm-hochschule.de
- update to 1.18.0.4 for Haskell Platform 2014.2.0.0
  * no upstream changelog
* Mon Sep  1 2014 peter.trommler@ohm-hochschule.de
- regenerate spec file with cabal-rpm 0.8.6
* Fri Aug 22 2014 peter.trommler@ohm-hochschule.de
- enable PowerPC builds
* Tue May  7 2013 peter.trommler@ohm-hochschule.de
- update to 1.16.0.2 from upstream
  * fix compilation issues with ghc 7.6
- part of Haskell Platform 2013.2
- more transparent packaging (fewer macros)
* Sat Nov 17 2012 peter.trommler@ohm-hochschule.de
- service localonly for Factory submission
* Tue Jun  5 2012 peter.trommler@ohm-hochschule.de
- update to 0.14.0 from upstream
- required for Haskell Platform 2012.2.0.0
* Sat Dec 31 2011 peter.trommler@ohm-hochschule.de
- Added other BR
- Fixed defattr
- Fixed filename in files
* Thu Dec  8 2011 peter.trommler@ohm-hochschule.de
- Added ghc-HTTP-devel to BR.
* Tue Nov  1 2011 peter.trommler@ohm-hochschule.de
- Initial packaging.
